| sstn | R Documentation |
The SSTN is a statistical test for assessing whether a given sample originates from a normal distribution. It is based on the iterative application of the empirical characteristic function and comparing these estimated characteristic functions. A Monte Carlo procedure is used to obtain the empirical distribution of the test statistic under the null hypothesis.
sstn(x, verbose = TRUE)
x |
Numeric vector of observations |
verbose |
Logical. If TRUE (default), prints a summary of the test results
including the number of summands, test statistic, and |
An invisible list with the following components:
test.statistic |
Numeric. The observed value of the SSTN test statistic. |
method |
Character string indicating whether the asymptotic or the finite-sample null distribution was used. |
p.value |
Numeric. The |
Akin Anarat akin.anarat@hhu.de
Anarat, A. and Schwender, H. (2026). A test for normality based on self-similarity. arXiv preprint doi:10.48550/arXiv.2604.03810.
set.seed(123)
# Sample from standard normal (null hypothesis true)
x <- rnorm(100)
res <- sstn(x)
res$p.value
# Sample from Gamma distribution (null hypothesis false)
y <- rgamma(100, 1)
res2 <- sstn(y)
res2$p.value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.